# openIMIS Backend claim_sampling reference module
This repository holds the files of the openIMIS Backend Claim Sampling reference module.

[![License: AGPL v3](https://img.shields.io/badge/License-AGPL%20v3-blue.svg)](https://www.gnu.org/licenses/agpl-3.0)

## Code climate (develop branch)

## ORM mapping:

## Listened Django Signals

## Services

## Reports (template can be overloaded via report.ReportDefinition)

## GraphQL Queries

## GraphQL Mutations - each mutation emits default signals and return standard error lists (cfr. openimis-be-core_py)

## Additional Endpoints

## Reports

## Configuration options (can be changed via core.ModuleConfiguration)


## openIMIS Modules Dependencies

